@@ -18,7 +18,7 @@ ASQL = os.getenv(
     "NB_ASQL", "postgresql+asyncpg://postgres:secret@postgres:5432/nb_workflows"
 )
 FILESERVER = os.getenv("NB_FILESERVER")
-FILESERVER_BUCKET = "nb-workflows"
+FILESERVER_BUCKET = "nbwf"
 
 # RQ_REDIS_HOST = os.getenv("NB_RQ_HOST", "redis")
 # RQ_REDIS_PORT = os.getenv("NB_RQ_PORT", "6379")
@@ -30,8 +30,6 @@ WORKFLOW_SERVICE = os.getenv("NB_WORKFLOW_SERVICE", "http://localhost:8000")
 # Logs
 LOGFORMAT = detailed_format
 
-EXECUTIONID_LEN = 8
-
 # General Folders for the server
 BASE_PATH = os.getenv("NB_BASEPATH", os.getcwd())
 SERVER_DATA_FOLDER = ".server_data/"
@@ -41,5 +39,3 @@ NB_WORKFLOWS = os.getenv("NB_WORKFLOWS", "workflows/")
 NB_OUTPUT = os.getenv("NB_NB_OUTPUT", "outputs/")
 NB_PROJECTS = "projects"
 DOCKER_RUNTIMES = "runtimes/"
-
-WF_UPLOADS = "uploads/"
