@@ -1,7 +1,8 @@
+from .client import WorkflowsFile
 from .core import (
+    ExecutionNBTask,
     ExecutionResult,
-    ExecutionTask,
-    ExecutionTask2,
+    HistoryLastResponse,
     HistoryRequest,
     HistoryResult,
     NBTask,
@@ -10,5 +11,6 @@ from .core import (
     ScheduleData,
     SimpleExecCtx,
     WorkflowData,
+    WorkflowDataWeb,
     WorkflowsList,
 )
